"""isort:skip_file"""

# flake8: noqa

from apysc._type.int import Int
from apysc._type.number import Number
from apysc._type.number import Number as Float
from apysc._type.boolean import Boolean
from apysc._type.boolean import Boolean as Bool
from apysc._type.string import String
from apysc._type.array import Array
from apysc._type.dictionary import Dictionary
from apysc._type.any_value import AnyValue
from apysc._branch._if import If
from apysc._branch._elif import Elif
from apysc._branch._else import Else
from apysc._loop._for import For
from apysc._loop._continue import Continue
from apysc._display.display_object import DisplayObject
from apysc._display._document import document
from apysc._display.sprite import Sprite
from apysc._display.graphics import Graphics
from apysc._display.stage import Stage
from apysc._display.stage import get_stage
from apysc._display.rectangle import Rectangle
from apysc._display.circle import Circle
from apysc._display.ellipse import Ellipse
from apysc._display.line import Line
from apysc._display.polyline import Polyline
from apysc._display.polygon import Polygon
from apysc._display.line_caps import LineCaps
from apysc._display.line_joints import LineJoints
from apysc._display.line_dot_setting import LineDotSetting
from apysc._display.line_dash_setting import LineDashSetting
from apysc._display.line_round_dot_setting import LineRoundDotSetting
from apysc._display.line_dash_dot_setting import LineDashDotSetting
from apysc._display.path import Path
from apysc._geom.point2d import Point2D
from apysc._geom.path_label import PathLabel
from apysc._geom.path_data_base import PathDataBase
from apysc._geom.path_move_to import PathMoveTo
from apysc._geom.path_line_to import PathLineTo
from apysc._geom.path_horizontal import PathHorizontal
from apysc._geom.path_vertical import PathVertical
from apysc._geom.path_close import PathClose
from apysc._geom.path_bezier_2d import PathBezier2D
from apysc._geom.path_bezier_2d_continual import PathBezier2DContinual
from apysc._geom.path_bezier_3d import PathBezier3D
from apysc._geom.path_bezier_3d_continual import PathBezier3DContinual
from apysc._geom.path_data import PathData
from apysc._event.event import Event
from apysc._event.mouse_event import MouseEvent
from apysc._event.wheel_event import WheelEvent
from apysc._event.timer_event import TimerEvent
from apysc._event.animation_event import AnimationEvent
from apysc._event.enter_frame_event import EnterFrameEvent
from apysc._event.mouse_event_type import MouseEventType
from apysc._console._trace import trace
from apysc._console._trace import trace as print
from apysc._console.assertion import assert_equal
from apysc._console.assertion import assert_not_equal
from apysc._console.assertion import assert_true
from apysc._console.assertion import assert_false
from apysc._console.assertion import assert_greater
from apysc._console.assertion import assert_greater_equal
from apysc._console.assertion import assert_less
from apysc._console.assertion import assert_less_equal
from apysc._console.assertion import assert_arrays_equal
from apysc._console.assertion import assert_arrays_not_equal
from apysc._console.assertion import assert_dicts_equal
from apysc._console.assertion import assert_dicts_not_equal
from apysc._console.assertion import assert_defined
from apysc._console.assertion import assert_undefined
from apysc._event.document_mouse_wheel_func import bind_wheel_event_to_document
from apysc._event.document_mouse_wheel_func import unbind_wheel_event_all_from_document
from apysc._event.document_mouse_wheel_func import unbind_wheel_event_from_document
from apysc._html.exporter import save_overall_html
from apysc._expression.expression_data_util import append_js_expression
from apysc._jupyter.jupyter_util import display_on_jupyter
from apysc._jupyter.jupyter_util import display_on_colaboratory
from apysc._time.fps import FPS
from apysc._time.timer import Timer
from apysc._time.datetime_ import DateTime
from apysc._html.debug_mode import set_debug_mode
from apysc._html.debug_mode import unset_debug_mode
from apysc._html.debug_mode import is_debug_mode
from apysc._html.debug_mode import add_debug_info_setting
from apysc._type._return import Return
from apysc._type._delete import delete
from apysc._animation.easing import Easing
from apysc._animation.animation_base import AnimationBase
from apysc._animation.animation_move import AnimationMove
from apysc._animation.animation_x import AnimationX
from apysc._animation.animation_y import AnimationY
from apysc._animation.animation_cx import AnimationCx
from apysc._animation.animation_cy import AnimationCy
from apysc._animation.animation_width import AnimationWidth
from apysc._animation.animation_height import AnimationHeight
from apysc._animation.animation_width_for_ellipse import AnimationWidthForEllipse
from apysc._animation.animation_height_for_ellipse import AnimationHeightForEllipse
from apysc._animation.animation_radius import AnimationRadius
from apysc._animation.animation_fill_alpha import AnimationFillAlpha
from apysc._animation.animation_fill_color import AnimationFillColor
from apysc._animation.animation_line_color import AnimationLineColor
from apysc._animation.animation_line_alpha import AnimationLineAlpha
from apysc._animation.animation_line_thickness import AnimationLineThickness
from apysc._animation.animation_rotation_around_center import AnimationRotationAroundCenter
from apysc._animation.animation_rotation_around_point import AnimationRotationAroundPoint
from apysc._animation.animation_scale_x_from_center import AnimationScaleXFromCenter
from apysc._animation.animation_scale_y_from_center import AnimationScaleYFromCenter
from apysc._animation.animation_scale_x_from_point import AnimationScaleXFromPoint
from apysc._animation.animation_scale_y_from_point import AnimationScaleYFromPoint
from apysc._animation.animation_parallel import AnimationParallel

__version__: str = "2.5.66"
